using UnityEngine;
using System.Collections;

public class DayNight : MonoBehaviour {

	public Light leftLight;
	public Color leftBackgroundColor;
	public Color leftAmbientColor;
	public Light rightLight;
	public Color rightBackgroundColor;
	public Color rightAmbientColor;
	public float margin;
	public Vector3 origin;
	
	public bool locked;
	
	private Camera _camera;
	private Transform _player;
	private float _lastFade;
	
	// Use this for initialization
	void Start () {
		_player = GameObject.FindGameObjectWithTag ( "Player" ).transform;
		_camera = GameObject.FindGameObjectWithTag ( "MainCamera" ).camera;
		locked = false;
		_lastFade = 0.5f;
	}
	
	// Update is called once per frame
	void Update () {
		if ( !locked )
		{
			float fade = ( _player.position.x - origin.x ) / margin / 2f + 0.5f;
			fade = Mathf.Min ( Mathf.Max ( fade, 0f ), 1f );
			
			_lastFade = Mathf.Lerp ( _lastFade, fade, Time.deltaTime * 2f );
			
			leftLight.intensity = 1 - _lastFade;
			rightLight.intensity = _lastFade;
			
			Color blendColor = Color.Lerp ( leftBackgroundColor, rightBackgroundColor, _lastFade );
			
			_camera.backgroundColor = blendColor;
			RenderSettings.fogColor = blendColor;
			RenderSettings.ambientLight = Color.Lerp ( leftAmbientColor, rightAmbientColor, _lastFade );
		}
	}
}
